dist_competing_risks

dist_competing_risks(
    components,
    minimum_of=True,
    dependency='Independent',
    correlation=None,
)

Competing-risks distribution.

The distribution of the minimum (a series system) or maximum (a parallel system) of several component random variables, with an optional dependency structure. Mirrors the C# CompetingRisks composite.

Parameters

Name Type Description Default
components sequence of Distribution The component distributions. required
minimum_of bool True for the distribution of the minimum of components; False for the maximum. True
dependency ('Independent', 'PerfectlyPositive', 'PerfectlyNegative', 'CorrelationMatrix') The dependency structure between components. "Independent"
correlation array - like A square correlation matrix; required when dependency = "CorrelationMatrix", ignored otherwise. None

Returns

Name Type Description
Distribution Family "CompetingRisks", accepted by every method every other :class:Distribution accepts.

Examples

>>> d = dist_competing_risks(
...     [Distribution("Weibull", [1, 2]), Distribution("Weibull", [1, 3])]
... )
>>> d.cdf(1.5) > 0
True